from __future__ import annotations

from typing import Annotated, TypeAlias

from pydantic import Field

from .message_origin_channel import MessageOriginChannel
from .message_origin_chat import MessageOriginChat
from .message_origin_hidden_user import MessageOriginHiddenUser
from .message_origin_user import MessageOriginUser

MessageOriginUnion: TypeAlias = Annotated[
    MessageOriginUser | MessageOriginHiddenUser | MessageOriginChat | MessageOriginChannel,
    Field(discriminator="type"),
]



from __future__ import annotations

from typing import TYPE_CHECKING, Any

from .base import TelegramObject

if TYPE_CHECKING:
    from .rich_block import RichBlock
    from .rich_block_union import RichBlockUnion


class RichMessage(TelegramObject):
    """
    Rich formatted message.

    Source: https://core.telegram.org/bots/api#richmessage
    """

    blocks: list[RichBlockUnion]
    """Content of the message"""
    is_rtl: bool | None = None
    """*Optional*. :code:`True`, if the rich message must be shown right-to-left"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            blocks: list[RichBlockUnion],
            is_rtl: bool | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(blocks=blocks, is_rtl=is_rtl, **__pydantic_kwargs)



from __future__ import annotations

from typing import Annotated, TypeAlias

from pydantic import Field

from .revenue_withdrawal_state_failed import RevenueWithdrawalStateFailed
from .revenue_withdrawal_state_pending import RevenueWithdrawalStatePending
from .revenue_withdrawal_state_succeeded import RevenueWithdrawalStateSucceeded

RevenueWithdrawalStateUnion: TypeAlias = Annotated[
    RevenueWithdrawalStatePending | RevenueWithdrawalStateSucceeded | RevenueWithdrawalStateFailed,
    Field(discriminator="type"),
]



from typing import TYPE_CHECKING, Any

from .base import TelegramMethod


class AnswerChatJoinRequestQuery(TelegramMethod[bool]):
    """
    Use this method to process a received chat join request query. Returns :code:`True` on success.

    Source: https://core.telegram.org/bots/api#answerchatjoinrequestquery
    """

    __returning__ = bool
    __api_method__ = "answerChatJoinRequestQuery"

    chat_join_request_query_id: str
    """Unique identifier of the join request query"""
    result: str
    """Result of the query. Must be either 'approve' to allow the user to join the chat, 'decline' to disallow the user to join the chat, or 'queue' to leave the decision to other administrators"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            chat_join_request_query_id: str,
            result: str,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                chat_join_request_query_id=chat_join_request_query_id,
                result=result,
                **__pydantic_kwargs,
            )



from __future__ import annotations

from typing import Annotated, TypeAlias

from pydantic import Field

from .chat_boost_source_gift_code import ChatBoostSourceGiftCode
from .chat_boost_source_giveaway import ChatBoostSourceGiveaway
from .chat_boost_source_premium import ChatBoostSourcePremium

ChatBoostSourceUnion: TypeAlias = Annotated[
    ChatBoostSourcePremium | ChatBoostSourceGiftCode | ChatBoostSourceGiveaway,
    Field(discriminator="source"),
]



from typing import TYPE_CHECKING, Any, Literal

from .input_poll_option_media import InputPollOptionMedia


class InputMediaLink(InputPollOptionMedia):
    """
    Represents an HTTP link to be sent.

    Source: https://core.telegram.org/bots/api#inputmedialink
    """

    type: Literal["link"] = "link"
    """Type of the media, must be *link*"""
    url: str
    """HTTP URL of the link"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            type: Literal["link"] = "link",
            url: str,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(type=type, url=url, **__pydantic_kwargs)



from __future__ import annotations

from typing import TYPE_CHECKING, Any

from ..types import BotCommand, BotCommandScopeUnion
from .base import TelegramMethod


class SetMyCommands(TelegramMethod[bool]):
    """
    Use this method to change the list of the bot's commands. See `this manual <https://core.telegram.org/bots/features#commands>`_ for more details about bot commands. Returns :code:`True` on success.

    Source: https://core.telegram.org/bots/api#setmycommands
    """

    __returning__ = bool
    __api_method__ = "setMyCommands"

    commands: list[BotCommand]
    """A JSON-serialized list of bot commands to be set as the list of the bot's commands. At most 100 commands can be specified"""
    scope: BotCommandScopeUnion | None = None
    """A JSON-serialized object, describing scope of users for which the commands are relevant. Defaults to :class:`aiogram.types.bot_command_scope_default.BotCommandScopeDefault`"""
    language_code: str | None = None
    """A two-letter ISO 639-1 language code. If empty, commands will be applied to all users from the given scope, for whose language there are no dedicated commands"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            commands: list[BotCommand],
            scope: BotCommandScopeUnion | None = None,
            language_code: str | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                commands=commands, scope=scope, language_code=language_code, **__pydantic_kwargs
            )



from __future__ import annotations

from typing import TYPE_CHECKING, Any

from .input_message_content import InputMessageContent

if TYPE_CHECKING:
    from .input_rich_message import InputRichMessage


class InputRichMessageContent(InputMessageContent):
    """
    Represents the `content <https://core.telegram.org/bots/api#inputmessagecontent>`_ of a rich message to be sent as the result of an inline query.

    Source: https://core.telegram.org/bots/api#inputrichmessagecontent
    """

    rich_message: InputRichMessage
    """The message to be sent"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__, *, rich_message: InputRichMessage, **__pydantic_kwargs: Any
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(rich_message=rich_message, **__pydantic_kwargs)



from __future__ import annotations

from typing import Annotated, TypeAlias

from pydantic import Field

from .background_type_chat_theme import BackgroundTypeChatTheme
from .background_type_fill import BackgroundTypeFill
from .background_type_pattern import BackgroundTypePattern
from .background_type_wallpaper import BackgroundTypeWallpaper

BackgroundTypeUnion: TypeAlias = Annotated[
    BackgroundTypeFill | BackgroundTypeWallpaper | BackgroundTypePattern | BackgroundTypeChatTheme,
    Field(discriminator="type"),
]



from enum import Enum


class RichBlockType(str, Enum):
    """
    This object represents a block in a rich formatted message.

    Source: https://core.telegram.org/bots/api#richtext
    """

    PARAGRAPH = "paragraph"
    HEADING = "heading"
    PRE = "pre"
    FOOTER = "footer"
    DIVIDER = "divider"
    MATHEMATICAL_EXPRESSION = "mathematical_expression"
    ANCHOR = "anchor"
    LIST = "list"
    BLOCKQUOTE = "blockquote"
    PULLQUOTE = "pullquote"
    COLLAGE = "collage"
    SLIDESHOW = "slideshow"
    TABLE = "table"
    DETAILS = "details"
    MAP = "map"
    ANIMATION = "animation"
    AUDIO = "audio"
    PHOTO = "photo"
    VIDEO = "video"
    VOICE_NOTE = "voice_note"
    THINKING = "thinking"



from __future__ import annotations

from typing import TYPE_CHECKING, Any, Literal

from ..enums import RichBlockType
from .base import TelegramObject
from .rich_block import RichBlock

if TYPE_CHECKING:
    from .rich_block import RichBlock
    from .rich_block_caption import RichBlockCaption
    from .rich_block_union import RichBlockUnion


class RichBlockSlideshow(RichBlock):
    """
    A slideshow, corresponding to the custom HTML tag :code:`<tg-slideshow>`.

    Source: https://core.telegram.org/bots/api#richblockslideshow
    """

    type: Literal[RichBlockType.SLIDESHOW] = RichBlockType.SLIDESHOW
    """Type of the block, always 'slideshow'"""
    blocks: list[RichBlockUnion]
    """Elements of the slideshow"""
    caption: RichBlockCaption | None = None
    """*Optional*. Caption of the block"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            type: Literal[RichBlockType.SLIDESHOW] = RichBlockType.SLIDESHOW,
            blocks: list[RichBlockUnion],
            caption: RichBlockCaption | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(type=type, blocks=blocks, caption=caption, **__pydantic_kwargs)



from __future__ import annotations

from typing import Annotated, TypeAlias

from pydantic import Field

from .input_paid_media_live_photo import InputPaidMediaLivePhoto
from .input_paid_media_photo import InputPaidMediaPhoto
from .input_paid_media_video import InputPaidMediaVideo

InputPaidMediaUnion: TypeAlias = Annotated[
    InputPaidMediaLivePhoto | InputPaidMediaPhoto | InputPaidMediaVideo,
    Field(discriminator="type"),
]



from .base import TelegramObject


class RichBlock(TelegramObject):
    """
    This object represents a block in a rich formatted message. Currently, it can be any of the following types:

     - :class:`aiogram.types.rich_block_paragraph.RichBlockParagraph`
     - :class:`aiogram.types.rich_block_section_heading.RichBlockSectionHeading`
     - :class:`aiogram.types.rich_block_preformatted.RichBlockPreformatted`
     - :class:`aiogram.types.rich_block_footer.RichBlockFooter`
     - :class:`aiogram.types.rich_block_divider.RichBlockDivider`
     - :class:`aiogram.types.rich_block_mathematical_expression.RichBlockMathematicalExpression`
     - :class:`aiogram.types.rich_block_anchor.RichBlockAnchor`
     - :class:`aiogram.types.rich_block_list.RichBlockList`
     - :class:`aiogram.types.rich_block_block_quotation.RichBlockBlockQuotation`
     - :class:`aiogram.types.rich_block_pull_quotation.RichBlockPullQuotation`
     - :class:`aiogram.types.rich_block_collage.RichBlockCollage`
     - :class:`aiogram.types.rich_block_slideshow.RichBlockSlideshow`
     - :class:`aiogram.types.rich_block_table.RichBlockTable`
     - :class:`aiogram.types.rich_block_details.RichBlockDetails`
     - :class:`aiogram.types.rich_block_map.RichBlockMap`
     - :class:`aiogram.types.rich_block_animation.RichBlockAnimation`
     - :class:`aiogram.types.rich_block_audio.RichBlockAudio`
     - :class:`aiogram.types.rich_block_photo.RichBlockPhoto`
     - :class:`aiogram.types.rich_block_video.RichBlockVideo`
     - :class:`aiogram.types.rich_block_voice_note.RichBlockVoiceNote`
     - :class:`aiogram.types.rich_block_thinking.RichBlockThinking`

    Source: https://core.telegram.org/bots/api#richblock
    """



from __future__ import annotations

from typing import TYPE_CHECKING, Any, Literal

from ..enums import RichBlockType
from .base import TelegramObject
from .rich_block import RichBlock

if TYPE_CHECKING:
    from .rich_text import RichText
    from .rich_text_union import RichTextUnion


class RichBlockSectionHeading(RichBlock):
    """
    A section heading, corresponding to the HTML tags :code:`<h1>`, :code:`<h2>`, :code:`<h3>`, :code:`<h4>`, :code:`<h5>`, or :code:`<h6>`.

    Source: https://core.telegram.org/bots/api#richblocksectionheading
    """

    type: Literal[RichBlockType.HEADING] = RichBlockType.HEADING
    """Type of the block, always 'heading'"""
    text: RichTextUnion
    """Text of the block"""
    size: int
    """Relative size of the text font; 1-6, 1 is the largest, 6 is the smallest"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            type: Literal[RichBlockType.HEADING] = RichBlockType.HEADING,
            text: RichTextUnion,
            size: int,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(type=type, text=text, size=size, **__pydantic_kwargs)



from __future__ import annotations

from typing import TYPE_CHECKING, Any

from .base import TelegramObject


class File(TelegramObject):
    """
    This object represents a file ready to be downloaded. The file can be downloaded via the link :code:`https://api.telegram.org/file/bot<token>/<file_path>`. It is guaranteed that the link will be valid for at least 1 hour. When the link expires, a new one can be requested by calling :class:`aiogram.methods.get_file.GetFile`.

     The maximum file size to download is 20 MB

    Source: https://core.telegram.org/bots/api#file
    """

    file_id: str
    """Identifier for this file, which can be used to download or reuse the file"""
    file_unique_id: str
    """Unique identifier for this file, which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file"""
    file_size: int | None = None
    """*Optional*. File size in bytes. It can be bigger than 2^31 and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a signed 64-bit integer or double-precision float type are safe for storing this value"""
    file_path: str | None = None
    """*Optional*. File path. Use :code:`https://api.telegram.org/file/bot<token>/<file_path>` to get the file"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            file_id: str,
            file_unique_id: str,
            file_size: int | None = None,
            file_path: str | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                file_id=file_id,
                file_unique_id=file_unique_id,
                file_size=file_size,
                file_path=file_path,
                **__pydantic_kwargs,
            )



from __future__ import annotations

from typing import TYPE_CHECKING, Any, Literal

from ..enums import RichBlockType
from .base import TelegramObject
from .rich_block import RichBlock

if TYPE_CHECKING:
    from .location import Location
    from .rich_block_caption import RichBlockCaption


class RichBlockMap(RichBlock):
    """
    A block with a map, corresponding to the custom HTML tag :code:`<tg-map>`.

    Source: https://core.telegram.org/bots/api#richblockmap
    """

    type: Literal[RichBlockType.MAP] = RichBlockType.MAP
    """Type of the block, always 'map'"""
    location: Location
    """Location of the center of the map"""
    zoom: int
    """Map zoom level; 13-20"""
    width: int
    """Expected width of the map"""
    height: int
    """Expected height of the map"""
    caption: RichBlockCaption | None = None
    """*Optional*. Caption of the block"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            type: Literal[RichBlockType.MAP] = RichBlockType.MAP,
            location: Location,
            zoom: int,
            width: int,
            height: int,
            caption: RichBlockCaption | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                type=type,
                location=location,
                zoom=zoom,
                width=width,
                height=height,
                caption=caption,
                **__pydantic_kwargs,
            )



from __future__ import annotations

from typing import TYPE_CHECKING, Any, Literal

from ..enums import RichBlockType
from .base import TelegramObject
from .rich_block import RichBlock

if TYPE_CHECKING:
    from .rich_block_list_item import RichBlockListItem


class RichBlockList(RichBlock):
    """
    A list of blocks, corresponding to the HTML tag :code:`<ul>` or :code:`<ol>` with multiple nested tags :code:`<li>`.

    Source: https://core.telegram.org/bots/api#richblocklist
    """

    type: Literal[RichBlockType.LIST] = RichBlockType.LIST
    """Type of the block, always 'list'"""
    items: list[RichBlockListItem]
    """Items of the list"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            type: Literal[RichBlockType.LIST] = RichBlockType.LIST,
            items: list[RichBlockListItem],
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(type=type, items=items, **__pydantic_kwargs)



from typing import Annotated, TypeAlias

from pydantic import Field

from .input_story_content_photo import InputStoryContentPhoto
from .input_story_content_video import InputStoryContentVideo

InputStoryContentUnion: TypeAlias = Annotated[
    InputStoryContentPhoto | InputStoryContentVideo, Field(discriminator="type")
]



from __future__ import annotations

from typing import TYPE_CHECKING, Any, Literal

from ..enums import RichBlockType
from .base import TelegramObject
from .rich_block import RichBlock

if TYPE_CHECKING:
    from .rich_block_table_cell import RichBlockTableCell
    from .rich_text import RichText
    from .rich_text_union import RichTextUnion


class RichBlockTable(RichBlock):
    """
    A table, corresponding to the HTML tag :code:`<table>`.

    Source: https://core.telegram.org/bots/api#richblocktable
    """

    type: Literal[RichBlockType.TABLE] = RichBlockType.TABLE
    """Type of the block, always 'table'"""
    cells: list[list[RichBlockTableCell]]
    """Cells of the table"""
    is_bordered: bool | None = None
    """*Optional*. :code:`True`, if the table has borders"""
    is_striped: bool | None = None
    """*Optional*. :code:`True`, if the table is striped"""
    caption: RichTextUnion | None = None
    """*Optional*. Caption of the table"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            type: Literal[RichBlockType.TABLE] = RichBlockType.TABLE,
            cells: list[list[RichBlockTableCell]],
            is_bordered: bool | None = None,
            is_striped: bool | None = None,
            caption: RichTextUnion | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                type=type,
                cells=cells,
                is_bordered=is_bordered,
                is_striped=is_striped,
                caption=caption,
                **__pydantic_kwargs,
            )
